@@ -1197,7 +1197,7 @@ class LaharFlowData(object):
 
         if crs is not None:
             if crs != wgs84:
-                raster.rio.reproject(crs, inplace=True)
+                raster = raster.rio.reproject(crs)
 
         if fileOut is None:
             fname, fext = os.path.splitext(fileIn)
